@@ -166,7 +166,7 @@ def para_find_homologs(seq1, seq2):
                 trans.append(res.result()[0])
                 distances.append(res.result()[1])
                 frames2.append(res.result()[2])
-    subprocess.call('rm tmp*.fasta out*.fasta', shell=True)
+    subprocess.call('rm tmpfilexyz*.fasta outfilexyz*.fasta', shell=True)
     del frames[distances.index(min(distances))]
     for i in frames:
         if min(distances) == 0:
@@ -196,7 +196,7 @@ def para_join_find_homologs(seqs, seq2):
                     trans.append(res.result()[0])
                     distances.append(res.result()[1])
                     frames2.append(res.result()[2])
-        subprocess.call('rm tmp*.fasta out*.fasta', shell=True)
+        subprocess.call('rm tmpfilexyz*.fasta outfilexyz*.fasta', shell=True)
         del frames[distances.index(min(distances))]
         for i in frames:
             if min(distances) == 0:
@@ -215,12 +215,12 @@ def test_frames(seq1, seq2, frame):
     trans0 = seq2[frame:].translate(stop_symbol='')
     stops = seq2[frame:].translate()
     to_align = [SeqRecord(seq1, id='Seq1'), SeqRecord(trans0, id='Seq2')]
-    SeqIO.write(to_align, 'tmp'+str(frame)+'.fasta', 'fasta')
-    kresult = invoke_kalign('tmp'+str(frame)+'.fasta', 'out'+str(frame)+'.fasta')
+    SeqIO.write(to_align, 'tmpfilexyz'+str(frame)+'.fasta', 'fasta')
+    kresult = invoke_kalign('tmpfilexyz'+str(frame)+'.fasta', 'outfilexyz'+str(frame)+'.fasta')
     if kresult == 1:
         return 1
     alignments = []
-    for record in SeqIO.parse('out'+str(frame)+'.fasta', 'fasta'):
+    for record in SeqIO.parse('outfilexyz'+str(frame)+'.fasta', 'fasta'):
         alignments.append(record.seq)
     alignments[0] = reinsert_star(seq1, alignments[0])
     trans = Seq(trim(alignments, stops))
@@ -238,17 +238,17 @@ def find_homologs(seq1, seq2):
         trans0 = seq2[i:].translate(stop_symbol='')
         stops = seq2[i:].translate()
         to_align = [SeqRecord(seq1, id='Seq1'), SeqRecord(trans0, id='Seq2')]
-        SeqIO.write(to_align, 'tmp.fasta', 'fasta')
-        kresult = invoke_kalign('tmp.fasta', 'out.fasta')
+        SeqIO.write(to_align, 'tmpfilexyz.fasta', 'fasta')
+        kresult = invoke_kalign('tmpfilexyz.fasta', 'outfilexyz.fasta')
         if kresult == 1:
             return 1
         alignments = []
-        for record in SeqIO.parse('out.fasta', 'fasta'):
+        for record in SeqIO.parse('outfilexyz.fasta', 'fasta'):
             alignments.append(record.seq)
         alignments[0] = reinsert_star(seq1, alignments[0])
         trans.append(Seq(trim(alignments, stops)))
         distances.append(distance(str(seq1), str(trans[-1])))
-    subprocess.call(['rm', 'tmp.fasta', 'out.fasta'])
+    subprocess.call(['rm', 'tmpfilexyz.fasta', 'outfilexyz.fasta'])
     inds = [0, 1, 2]
     del inds[distances.index(min(distances))]
     for i in inds:
@@ -271,17 +271,17 @@ def join_find_homologs(seqs, seq2):
             stops = seq2[i:].translate()
             to_align = [SeqRecord(seq, id='Seq1'),
                         SeqRecord(trans0, id='Seq2')]
-            SeqIO.write(to_align, 'tmp.fasta', 'fasta')
-            kresult = invoke_kalign('tmp.fasta', 'out.fasta')
+            SeqIO.write(to_align, 'tmpfilexyz.fasta', 'fasta')
+            kresult = invoke_kalign('tmpfilexyz.fasta', 'outfilexyz.fasta')
             if kresult == 1:
                 return 1
             alignments = []
-            for record in SeqIO.parse('out.fasta', 'fasta'):
+            for record in SeqIO.parse('outfilexyz.fasta', 'fasta'):
                 alignments.append(record.seq)
             alignments[0] = reinsert_star(seq, alignments[0])
             trans.append(Seq(trim(alignments, stops)))
             distances.append(distance(str(seq), str(trans[-1])))
-        subprocess.call(['rm', 'tmp.fasta', 'out.fasta'])
+        subprocess.call(['rm', 'tmpfilexyz.fasta', 'outfilexyz.fasta'])
         inds = [0, 1, 2]
         del inds[distances.index(min(distances))]
         for i in inds:
@@ -313,10 +313,10 @@ def join_find_homologs(seqs, seq2):
 def detect_frameshift(ref, read):
     records = [SeqRecord(ref, id='reference'),
                SeqRecord(read.translate(), id='read')]
-    SeqIO.write(records, 'tmp.fasta', 'fasta')
-    invoke_kalign('tmp.fasta', 'out.fasta')
+    SeqIO.write(records, 'tmpfilexyz.fasta', 'fasta')
+    invoke_kalign('tmpfilexyz.fasta', 'outfilexyz.fasta')
     seqs = {}
-    for record in SeqIO.parse('out.fasta', 'fasta'):
+    for record in SeqIO.parse('outfilexyz.fasta', 'fasta'):
         seqs[record.id] = str(record.seq)
     distances = []
     for i in range(0, len(seqs['reference'])-30, 10):
@@ -329,18 +329,18 @@ def detect_frameshift(ref, read):
     new_distances = [distance(seqs['reference'], seqs['read'])]
     records = [SeqRecord(ref, id='reference'),
                SeqRecord((read[:ind]+'A'+read[ind:]).translate())]
-    SeqIO.write(records, 'tmp.fasta', 'fasta')
-    invoke_kalign('tmp.fasta', 'out.fasta')
-    for record in SeqIO.parse('out.fasta', 'fasta'):
+    SeqIO.write(records, 'tmpfilexyz.fasta', 'fasta')
+    invoke_kalign('tmpfilexyz.fasta', 'outfilexyz.fasta')
+    for record in SeqIO.parse('outfilexyz.fasta', 'fasta'):
         seqs[record.id] = str(record.seq)
     new_distances.append(distance(seqs['reference'], seqs['read']))
     records = [SeqRecord(ref, id='reference'),
                SeqRecord((read[:ind]+'AA'+read[ind:]).translate())]
-    SeqIO.write(records, 'tmp.fasta', 'fasta')
-    invoke_kalign('tmp.fasta', 'out.fasta')
-    for record in SeqIO.parse('out.fasta', 'fasta'):
+    SeqIO.write(records, 'tmpfilexyz.fasta', 'fasta')
+    invoke_kalign('tmpfilexyz.fasta', 'outfilexyz.fasta')
+    for record in SeqIO.parse('outfilexyz.fasta', 'fasta'):
         seqs[record.id] = str(record.seq)
-    subprocess.call(['rm', 'out.fasta', 'tmp.fasta'])
+    subprocess.call(['rm', 'outfilexyz.fasta', 'tmpfilexyz.fasta'])
     new_distances.append(distance(seqs['reference'], seqs['read']))
     if (new_distances[1] <= new_distances[0] or
        new_distances[2] <= new_distances[0]):
@@ -496,17 +496,53 @@ def compressor(seqs, names, ids, og_seqs):
             new_og_seqs[new_ids[-1]] = og_seqs[same[0]]
     return new_seqs, new_names, new_ids, new_og_seqs
 
+# Check input FASTA
+def check_input(reference, reads):
+    records = []
+    try:
+        for record in SeqIO.parse(reference, 'fasta'):
+            records.append(records)
+        if len(records) != 1:
+            print('User Error: reference input should contain exactly one sequence')
+            exit()
+        records = []
+        for record in SeqIO.parse(reads, 'fasta'):
+            records.append(record)
+        if len(records) == 0:
+            print('User Error: sequence FASTA file is empty')
+            exit()
+    except:
+        print('User Error: improperly formated FASTA')
+
+
 
 # For when inputs are whole genomes
-def genome_mode(reference, reads, start, end, compress):
+def genome_mode(reference, reads, start, end, compress, para):
+    check_input(reference, reads)
+    # Check that start and end coordinates are present and valid
     if ',' not in str(start) and ',' not in str(end):
-        start = int(start)-1
-        end = int(end)
+        try:
+            start = int(start)-1
+            end = int(end)
+        except:
+            print('User Error: invalid start/end coordinate(s)')
+            exit()
         join = 0
+        if start >= end:
+            print('User Error: start coordinate(s) must be less than the end coordinate(s)')
+            exit()
     else:
-        start = (int(start.split(',')[0])-1, int(start.split(',')[1])-1)
-        end = (int(end.split(',')[0]), int(end.split(',')[1]))
+        try:
+            start = (int(start.split(',')[0])-1, int(start.split(',')[1])-1)
+            end = (int(end.split(',')[0]), int(end.split(',')[1]))
+        except:
+            print('User Error: invalid start/end coordinate(s)')
+            exit()
         join = 1
+        if start[0] >= end[0] or start[1] >= end[1]:
+            print('User Error: start coordinate(s) must be less than the end coordinate(s)')
+            exit()
+
     # Find protein sequence of gene of interest and extract the original DNA
     # sequence (only for genome mode)
     og_seqs = {}
@@ -548,6 +584,7 @@ def genome_mode(reference, reads, start, end, compress):
 
 # For when inputs are in-frame genes
 def gene_mode(reference, reads, compress):
+    check_input(reference, reads)
     ids = []
     names = []
     seqs = []
@@ -584,7 +621,8 @@ def gene_mode(reference, reads, compress):
 
 
 # For when reference input is an in-frame gene but the reads are whole genomes
-def mixed_mode(reference, reads, compress):
+def mixed_mode(reference, reads, compress, para):
+    check_input(reference, reads)
     join = 0
     og_seqs = {}
     for record in SeqIO.parse(reference, 'fasta'):
